@@ -81,13 +81,14 @@ Calculate g-star statistic for spatial unit in relation to neighbors.
 
 The Gi* star statistic can be considered a standard normal variate.  So, the the cumulative probability of G*i(k_max) would be the cdf value for the standard normal distribution of the value G*i(k_max).  This value could be close to 1, but could also be much closer to zero in some cases.  So, using equation 2 of the AMOEBA paper, elements in the k_max level of contiguity would have zero weights with unit i.  These units are at the edge of the ecotope centered on i.  The units closer to i would have positive weights that increase as proximity to i increases. The value Gi*(0) is the Gi* value for the unit itself.
         """
-        if values_num == 1:
-            return 0.
-        return (values_sum - self.average * values_num) / (
-            self.pseudo_std * sqrt(
-                (self.number - values_num) * values_num / (self.number - 1)
+        try:
+            return (values_sum - self.average * values_num) / (
+                self.pseudo_std * sqrt(
+                    (self.number - values_num) * values_num / (self.number - 1)
                 )
             )
+        except ZeroDivisionError:
+            return 0.
 
     def get_trend(self, obj, tiers):
         """Do a first round of expansion, and determine the trend direction"""
